"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const clipanion_1 = require("clipanion");
const Workspace_1 = __importDefault(require("../core/Workspace"));
const helpers_1 = require("../helpers");
function MissingWorkspaceThemeError(workspace) {
    const message = [
        `Unable to find theme "${workspace.getCurrentThemeName()}" in workspace "${workspace.name}".`,
    ];
    throw new clipanion_1.UsageError(message.join('\n'));
}
function ConfigToConsole(name, config) {
    console.log(``);
    console.log(`${name}:`);
    config.toConsole();
}
exports.default = async (args) => {
    const workspaceExists = await Workspace_1.default.exists(args.workspace);
    if (!workspaceExists) {
        (0, helpers_1.MissingWorkspaceError)(args.workspace);
    }
    const workspace = await Workspace_1.default.init(args.workspace);
    ConfigToConsole('CLI Config', workspace.config);
    ConfigToConsole('Portal Config', workspace.portalConfig);
    ConfigToConsole('Router Config', workspace.routerConfig);
    try {
        const theme = await workspace.getCurrentTheme();
        ConfigToConsole('Theme Config Options', theme.config);
        theme.outputStatsToConsole();
    }
    catch (e) {
        MissingWorkspaceThemeError(workspace);
    }
};
