"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ora_1 = __importDefault(require("ora"));
const Workspace_1 = __importDefault(require("../core/Workspace"));
const RestClient_1 = __importDefault(require("../core/HTTP/RestClient"));
const helpers_1 = require("../helpers");
exports.default = async (args) => {
    var _a;
    let workspace;
    try {
        workspace = await Workspace_1.default.init(args.workspace, args.disableSSLVerification, args.ignoreSpecs, args.skipPath);
    }
    catch (e) {
        return (0, helpers_1.MissingWorkspaceError)(args.workspace);
    }
    const client = new RestClient_1.default(workspace.config, workspace.name);
    const spinner = (0, ora_1.default)({
        prefixText: `Wiping...`,
        text: `reading files...`,
    }).start();
    let files;
    try {
        files = await client.getAllFiles({ fields: 'path' });
        if (workspace.config.skipPaths && workspace.config.skipPaths.length > 0) {
            files = files.filter((file) => !workspace.config.skipPaths.some((path) => { var _a; return (_a = file.path) === null || _a === void 0 ? void 0 : _a.startsWith(path); }));
        }
        for (const file of files) {
            if (workspace.config.ignoreSpecs && ((_a = file.path) === null || _a === void 0 ? void 0 : _a.startsWith('specs'))) {
                continue;
            }
            spinner.text = file.path || file.id || 'file';
            await client.deleteFile(file);
        }
    }
    catch (e) {
        spinner.text = client.handleError(e);
        spinner.fail();
        return;
    }
    spinner.prefixText = `\t`;
    spinner.text = workspace.config.ignoreSpecs
        ? `Wiped all non-spec Files from ${workspace.name}`
        : `Wiped all Files from ${workspace.name}`;
    spinner.succeed();
};
