"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rs = __importStar(require("recursive-readdir-async"));
const fs = __importStar(require("fs-extra"));
const upath_1 = require("upath");
const Config_1 = __importDefault(require("./Config"));
const File_1 = __importDefault(require("./File"));
class WorkspaceTheme {
    constructor(location, name) {
        this.name = name;
        this.location = location;
        this.path = WorkspaceTheme.getDirectoryPath(location, name);
        this.config = new Config_1.default(this.path, 'theme.conf.yaml');
        this.assetsPath = (0, upath_1.join)(this.path, 'assets');
        this.layoutsPath = (0, upath_1.join)(this.path, 'layouts');
        this.partialsPath = (0, upath_1.join)(this.path, 'partials');
        this.assets = null;
        this.layouts = null;
        this.partials = null;
    }
    async scanAssets() {
        const assets = await rs.list(this.assetsPath, { exclude: ['.DS_Store'] });
        this.assets = this.mapFilesToContent(assets);
    }
    async scanLayouts() {
        const layouts = await rs.list(this.layoutsPath, { exclude: ['.DS_Store'] });
        this.layouts = this.mapFilesToContent(layouts);
    }
    async scanPartials() {
        const partials = await rs.list(this.partialsPath, { exclude: ['.DS_Store'] });
        this.partials = this.mapFilesToContent(partials);
    }
    mapFilesToContent(files) {
        return files.map((file) => {
            return new File_1.default(file.fullname, this.location);
        });
    }
    async addLayout() {
        console.log('not yet implemented');
    }
    async addPartial() {
        console.log('not yet implemented');
    }
    outputStatsToConsole() {
        const assetsLength = this.assets ? this.assets.length : 0;
        const layoutsLength = this.layouts ? this.layouts.length : 0;
        const partialsLength = this.partials ? this.partials.length : 0;
        console.log(``);
        console.log(`Total Theme Files:`, assetsLength + layoutsLength + partialsLength);
        console.log(`  `, `Assets:`, assetsLength);
        console.log(`  `, `Layouts:`, layoutsLength);
        console.log(`  `, `Partials:`, partialsLength);
    }
    static async init(location, name) {
        const theme = new WorkspaceTheme(location, name);
        await theme.config.load();
        await theme.scanAssets();
        await theme.scanLayouts();
        await theme.scanPartials();
        return theme;
    }
    static async exists(location, name) {
        try {
            const stat = await fs.lstat(WorkspaceTheme.getDirectoryPath(location, name));
            return stat && stat.isDirectory();
        }
        catch (e) {
            return false;
        }
    }
    static getDirectoryPath(location, name) {
        return (0, upath_1.join)(location, 'themes', name);
    }
}
exports.default = WorkspaceTheme;
